# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify CentOS Linux and Scientific Linux as rhel
%if "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "sl" || "%{__distinit}" == "sls"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

Summary:	A library that performs asynchronous DNS operations
Name:		c-ares
Version:	1.12.0
Release:	2.0.cf.%{__distinit}%{__distvers}
# The license can be obtained at http://c-ares.haxx.se/license.html
License:	MIT
Group:		System Environment/Libraries
URL:		http://c-ares.haxx.se/
Source0:	http://c-ares.haxx.se/download/c-ares-%{version}.tar.gz
Patch0:		c-ares-1.7.5-optflags.patch
BuildRoot:	%{_tmppath}/%{name}-%{version}-%{release}-root-%(id -nu)
BuildRequires:	coreutils
BuildRequires:	gcc
BuildRequires:	make

%description
c-ares is a C library that performs DNS requests and name resolves
asynchronously. c-ares is a fork of the library named 'ares', written
by Greg Hudson at MIT.

%package devel
Summary:	Development files for c-ares
Group:		Development/Libraries
Requires:	%{name} = %{version}-%{release}
Requires:	pkgconfig

%description devel
This package contains the header files and libraries needed to
compile applications or shared objects that use c-ares.

%prep
%setup -q

# Enable use of the appropriate compiler flags
%patch0 -p1 -b .optflags

%build
%configure \
	--disable-dependency-tracking \
	--disable-silent-rules \
	--disable-static \
	--disable-tests \
	--enable-shared
make %{?_smp_mflags}

%install
rm -rf %{buildroot}
make DESTDIR=%{buildroot} install
rm -f %{buildroot}%{_libdir}/libcares.la

%clean
rm -rf %{buildroot}

%post -p /sbin/ldconfig
%postun -p /sbin/ldconfig

%files
%if 0%{?_licensedir:1}
%license LICENSE.md
%else
%doc LICENSE.md
%endif
%doc AUTHORS CHANGES NEWS
%doc README.cares README.md RELEASE-NOTES TODO
%{_libdir}/libcares.so.*

%files devel
%{_includedir}/ares.h
%{_includedir}/ares_build.h
%{_includedir}/ares_dns.h
%{_includedir}/ares_rules.h
%{_includedir}/ares_version.h
%{_libdir}/libcares.so
%{_libdir}/pkgconfig/libcares.pc
%{_mandir}/man3/ares_*.3*

%changelog
* Fri Feb 10 2017 Paul Howarth <paul@city-fan.org> - 1.12.0-2.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Fri Sep 30 2016 Paul Howarth <paul@city-fan.org> - 1.12.0-1.0.cf
- Update to 1.12.0
  - api: Add ARES_OPT_NOROTATE optmask value
  - CVE-2016-5180: ares_create_query single byte out of buffer write
  - configure: Acknowledge --disable-tests
  - man pages: Fix typos detected by Lintian
  - test: Add missing #includes for dns-proto.cc
  - test: Avoid in6addr_* constants
  - test: Build with MinGW on AppVeyor
  - Makefile.m32: Add support for extra flags
  - Makefile.m32: Add support for CROSSPREFIX
  - configure: Check if tests can get built before enabled
  - ares_library_cleanup: Reset ares_realloc too
  - ahost.c: Add cast to fix C++ compile
  - test: Only pass unused args to GoogleTest
  - build: Commonize MSVC version detection
  - msvc_ver.inc: Support Visual Studio 2015 Update 1, 2, 3
  - test: For AF_UNSPEC, return CNAME only for AAAA, but valid A record
  - ares_getnameinfo: Explicitly clear struct servent before use
  - test: Update fuzzing function prototype
  - init: Fix nsort initialization
  - test: add fuzzing check script to tests
  - web: http => https
  - read_tcp_data: Remove superfluous NULL check
  - LICENSE.md: Add a stand-alone license file
  - SECURITY.md: Suggested "security process" for the project
  - ares_init_options: Only propagate init failures from options
  - headers: Remove checks for and defines of variable sizes
  - test: Fix gMock to work with gcc ≥ 6.x

* Fri Feb 19 2016 Paul Howarth <paul@city-fan.org> - 1.11.0-1.0.cf
- Update to 1.11.0
  - Add a unit test suite
  - Allow builds with code coverage with --enable-code-coverage configure option
  - Allow library-wide override of malloc/free
  - Allow multiple -s options to the ahost command
  - api: Expose the ares_library_initialized() function
  - api: Add ares_set_sortlist(3) entrypoint
  - api: Add entrypoints to allow use of per-server ports
  - api: Introduce 'ares_parse_txt_reply_ext`
  - api: Add ares_set_socket_configure_callback()
  - timeadd: Make static
  - timeoffset: Made static and private
  - nowarn: Use <limits.h> instead of configure for size of long
  - single_domain: Invalid memory access for empty string input
  - ares_build.h: Fix building on 64-bit powerpc
  - Allow specification of search domain in ahost
  - Don't override explicitly specified search domains
  - ares_parse_soa_reply: Do not leak rr_name on allocation failure
  - Update ahost man page to describe -s option
  - host_callback: Fall back to AF_INET on searching with AF_UNSPEC
  - Add -t u option to ahost
  - CONTRIBUTING: Added
  - ares_set_servers_csv: Fix NULL dereference
  - Fix integer shift overflow if both tcp_socket and udp_socket are set
  - Fix acountry memory leak
  - lookup_service: Prevent tmpbuf from overrunning
  - ares_getnameinfo.3: There is no ares_getaddrinfo
  - init_by_defaults: Continue loop if space for hostname not large enough
  - Destroy options if ares_save_options fails
  - ares__read_line: free buf on realloc failure
  - Added define for visual studio 2013
  - windows: Fix slow DNS lookup issue
  - Use libresolv to initialize cares on iPhone targets
  - buildconf: Remove check for libtool, it only requires libtoolize
  - init_by_resolv_conf: Don't exit loop early leaving uninitialized entries
  - ahost: Check the select() return code
  - configure_socket: Explicitly ignore return code
  - read_tcp_data: Don't try to use NULL pointer after malloc failure
  - Distribute all man pages
  - ares_expand_name: Check for valid bits in label length
  - ares__read_line: Clear buf pointer on realloc failure
  - process_answer: Fix things up correctly when removing EDNS option
  - ares_parse_txt_reply: Propagate errors from per-substring loop
  - ares_gethostbyname: Don't leak valid-but-empty hostent
  - ares_init_options: Don't lose init failure
  - ares_dup: Clear new channel on failure
  - config_sortlist: Free any existing sortlist on (re)alloc failure
  - ares_striendstr: Fix so non-NULL return can happen
  - bitncmp: Update comment to match code behaviour
  - ares_set_servers_csv.3: Make return type match code
  - init_by_resolv_conf: Ignore 'fopen' errors to use default values
  - Use "resolve" as synonym of "dns" in nsswitch.conf
  - ares_win32_init: Make LoadLibrary work when using UNICODE too
  - dist: Distribute README.md
  - configure: Build silently by default
  - ares_dup.3: Remove mention of nonexistent function
- Drop multilib patch, no longer needed
- Avoid trying to run the test suite for now since Fedora gmock/gtest seems to
  be borked
- Add upstream support for disabling tests
  (https://github.com/c-ares/c-ares/issues/44)

* Thu Feb  4 2016 Paul Howarth <paul@city-fan.org> - 1.10.0-6.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Sun Jun 21 2015 Paul Howarth <paul@city-fan.org> - 1.10.0-5.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Tue Aug 19 2014 Paul Howarth <paul@city-fan.org> - 1.10.0-4.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Mon Apr 28 2014 Paul Howarth <paul@city-fan.org> - 1.10.0-3.0.cf
- Drop %%defattr, redundant since rpm 4.4

* Sun Aug  4 2013 Paul Howarth <paul@city-fan.org> - 1.10.0-2.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Sun May 12 2013 Paul Howarth <paul@city-fan.org> - 1.10.0-1.0.cf
- Update to 1.10.0
  - Added ares_create_query(), to be used instead of ares_mkquery()
  - ares_inet_ntop() and ares_inet_pton() are now recognized c-ares functions
  - Include the ares_parse_soa_reply.* files in the tarball
  - read_udp_packets: bail out loop on bad sockets
  - get_DNS_AdaptersAddresses: fix IPv6 parsing
  - adig: perror() doesn't work for socket errors on windows
  - ares_parse_aaaa_reply: fix memory leak
  - setup_once.h: HP-UX <sys/socket.h> issue workaround
  - configure: several fixes
  - config-dos.h: define strerror() to strerror_s_() for High-C
  - config-dos.h: define HAVE_CLOSE_S for MSDOS/Watt-32
  - ares_build.h.dist: enhance non-configure GCC ABI detection logic
  - ares.h: stricter CARES_EXTERN linkage decorations logic
  - ares_cancel(): cancel requests safely
  - Protocol parsing: check input data more strictly
  - Library init: be recursive, reference count inits/cleanups
  - ares_parse_txt_reply: return a ares_txt_reply node for each sub-string
  - ares_set_servers_csv: fixed IPv6 address parsing
  - Build: fix build on msvc11
- Revert to old method of ensuring we use our compiler flags

* Sat Apr 13 2013 Paul Howarth <paul@city-fan.org> - 1.9.1-6.0.cf
- Apply some autotools fixes, but avoid the need to run autoreconf during the
  build process

* Sat Feb 23 2013 Paul Howarth <paul@city-fan.org> - 1.9.1-4.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Wed Aug  8 2012 Paul Howarth <paul@city-fan.org> - 1.9.1-3.0.cf
- Include URL to the license text

* Tue Jul 24 2012 Paul Howarth <paul@city-fan.org> - 1.9.1-2.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Tue Jun 19 2012 Paul Howarth <paul@city-fan.org> - 1.9.1-1.0.cf
- Update to 1.9.1
  - Include the ares_parse_soa_reply.* files in the tarball

* Mon Jun 18 2012 Paul Howarth <paul@city-fan.org> - 1.9.0-1.0.cf
- Update to 1.9.0
  - Added ares_parse_soa_reply
  - Fixed libcares.pc generation for static MingW* cross builds
  - ares_dup: fixed UDP and TCP port byte order in saved options

* Sat Apr 28 2012 Paul Howarth <paul@city-fan.org> - 1.8.0-1.0.cf
- Update to 1.8.0
  - Added ares_parse_naptr_reply()
  - Handle CNAME-only in ares_parse_aaaa_reply()
  - Support multiple DNS servers on Android
  - Check for __ANDROID__ in addition to ANDROID macro
  - Port numbers: convert them to network order
  - get_iphlpapi_dns_info: fix buffer overrun
  - configure: make CURL_CHECK_DEF ignore leading whitespace
  - Segfault triggered in ares_init_options()
  - ares_getnameinfo's memcpy did not copy enough bytes
  - ares_destroy: fix segfault in ares_destroy_options()
  - CHANGES: generate from script
  - configure: fix symbol hiding usability check
- Drop UTF-8 patch, no longer needed
- Update multilib patch

* Wed Jan 18 2012 Paul Howarth <paul@city-fan.org> - 1.7.5-2.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Wed Aug 17 2011 Paul Howarth <paul@city-fan.org> - 1.7.5-1.0.cf
- Update to 1.7.5
  - Detection of semicolon comments in resolv.conf
  - Avoid using system's inet_net_pton affected by the WLB-2008080064 advisory
  - Replacement ares_inet_net_pton affected by the WLB-2008080064 advisory
  - Replacement ares_inet_ntop affected by potential out of bounds write
  - Added install target to Makefile.msvc
  - Only fall back to AF_INET searches when looking for AF_UNSPEC addresses
  - Fixed ares_parse_*_reply memory leaks
  - Use correct sizeof in ares_getnameinfo()
  - IPv6-on-windows: find DNS servers correctly
  - man pages: docs for the c-ares utility programs
  - getservbyport replacement for Win CE
  - config_sortlist: (win32) missing else
  - advance_tcp_send_queue: avoid NULL ptr dereference
  - configure: fix a bashism
  - ares_expand_name: Fix encoded length for indirect root
- Rebase optflags patch to match the 1.7.5 code
- Drop upstreamed typecasts patch
- Use patch rather than scripted iconv to fix character encoding of CHANGES
- Fix Source0 URL to point at the upstream tarball
- Fix dist tag for CentOS 6 and Scientific Linux

* Mon Apr 11 2011 Paul Howarth <paul@city-fan.org> - 1.7.4-3.0.cf
- Apply upstream patch to fix unsafe typecasts (#695424)
- Nobody else likes macros for commands

* Sun Mar 27 2011 Paul Howarth <paul@city-fan.org> - 1.7.4-2.1.cf
- Remove mention of static libraries from %%description of devel package

* Fri Feb 11 2011 Paul Howarth <paul@city-fan.org> - 1.7.4-2.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Thu Dec  9 2010 Paul Howarth <paul@city-fan.org> - 1.7.4-1.0.cf
- Update to 1.7.4
  - Support binding to local interface/IPs: see ares_set_local_ip4,
    ares_set_local_ip6, ares_set_local_dev
  - Fix memory leak in ares_getnameinfo
  - Add missing break that caused get_ares_servers to fail
  - Fix CNAME response parsing in ares_parse_a_reply
  - Don't copy an empty sortlist in init_by_options
  - Replace uint32_t with unsigned int to fix broken builds on a couple of
    platforms
  - Fix lookup with HOSTALIASES set
  - Fix NAPTR parsing in adig
  - Compiler warning cleanups
- Drop upstream patches, now included in release

* Wed Aug 25 2010 Paul Howarth <paul@city-fan.org> - 1.7.3-3.0.cf
- Apply fixes from upstream 1.7.4 development:
  - Add missing break that caused get_ares_servers to fail
  - Fix aliasing warning in gcc 4.4.4 (at least)
  - Fix memory leak in ares_getnameinfo

* Tue Jun 15 2010 Paul Howarth <paul@city-fan.org> - 1.7.3-1.1.cf
- Fix multilib file conflict in c-ares-devel (#602880)

* Fri Jun 11 2010 Paul Howarth <paul@city-fan.org> - 1.7.3-1.0.cf
- Update to 1.7.3
  - Builds on Android
  - Now includes all files necessary to build it (1.7.2 lacked a file)

* Thu Jun 10 2010 Paul Howarth <paul@city-fan.org> - 1.7.2-1.0.cf
- Update to 1.7.2
  - Added ares_parse_mx_reply()
  - ares_init: Last, not first instance of domain or search should win
  - Improve alternative definition of bool
  - Fix VS2010 compiler warnings

* Fri May 14 2010 Paul Howarth <paul@city-fan.org> - 1.7.1-2.0.cf
- Fix dist tag for RHEL-6 Beta

* Tue Mar 23 2010 Paul Howarth <paul@city-fan.org> - 1.7.1-1.0.cf
- Update to 1.7.1 (added IPv6 name servers support)
- Drop IPv6 nameserver patch

* Sun Mar  7 2010 Jakub Hrozek <jhrozek@redhat.com> - 1.7.0-3.0.cf
- Change IPv6 nameserver patch according to upstream changes
  (upstream revisions 1199,1201,1202)

* Wed Mar  3 2010 Jakub Hrozek <jhrozek@redhat.com> - 1.7.0-2.0.cf
- Add a patch to allow usage of IPv6 nameservers
- Sync optflags patch with Fedora version

* Tue Dec  1 2009 Paul Howarth <paul@city-fan.org> - 1.7.0-1.0.cf
- Update to 1.7.0 (see RELEASE-NOTES for details)
- New header files ares_build.h and ares_rules.h to package
- Update optflags patch
- Dist tag for Rawhide no longer needs special-casing

* Wed Nov  4 2009 Paul Howarth <paul@city-fan.org> - 1.6.0-3.0.cf
- Import from Fedora
- Drop unbundled LICENSE file
- Add docs RELEASE-NOTES TODO AUTHORS

* Sat Jul 25 2009 Ville Skyttä <ville.skytta at iki.fi> - 1.6.0-3
- Patch to make upstream build system honor our CFLAGS and friends.
- Don't bother building throwaway static libs.
- Disable autotools dependency tracking for cleaner build logs and possible
  slight build speedup.
- Convert docs to UTF-8.
- Update URLs.

* Fri Jul 24 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.6.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Wed Jul 22 2009 Tom "spot" Callaway <tcallawa@redhat.com> - 1.6.0-1
- update to 1.6.0

* Mon Feb 23 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.5.3-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Fri Sep 12 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 1.5.3-1
- update to 1.5.3

* Tue Feb 19 2008 Fedora Release Engineering <rel-eng@fedoraproject.org> - 1.5.1-2
- Autorebuild for GCC 4.3

* Tue Feb 19 2008 Tom "spot" Callaway <tcallawa@redhat.com> 1.5.1-1
- update to 1.5.1

* Thu Aug 23 2007 Tom "spot" Callaway <tcallawa@redhat.com> 1.4.0-2
- rebuild for ppc32

* Wed Jun 27 2007 Tom "spot" Callaway <tcallawa@redhat.com> 1.4.0-1
- bump to 1.4.0 (resolves bugzilla 243591)
- get rid of static library (.a)

* Wed Jan 17 2007 Tom "spot" Callaway <tcallawa@redhat.com> 1.3.2-1
- bump to 1.3.2

* Mon Sep 11 2006 Tom "spot" Callaway <tcallawa@redhat.com> 1.3.1-2
- FC-6 bump

* Mon Jul 10 2006 Tom "spot" Callaway <tcallawa@redhat.com> 1.3.1-1
- bump to 1.3.1

* Tue Feb 28 2006 Tom "spot" Callaway <tcallawa@redhat.com> 1.3.0-2
- bump for FC-5 rebuild

* Sun Sep  4 2005 Tom "spot" Callaway <tcallawa@redhat.com> 1.3.0-1
- include LICENSE text
- bump to 1.3.0

* Tue May 31 2005 Tom "spot" Callaway <tcallawa@redhat.com> 1.2.1-4
- use dist tag to prevent EVR overlap

* Fri Apr 22 2005 Tom "spot" Callaway <tcallawa@redhat.com> 1.2.1-2
- fix license (MIT, not LGPL)
- get rid of libcares.la

* Fri Apr 22 2005 Tom "spot" Callaway <tcallawa@redhat.com> 1.2.1-1
- initial package creation

